Flask-AppBuilder
================

.. module:: flask_appbuilder

Simple and rapid application development framework, built on top of `Flask <http://flask.pocoo.org/>`_.
Includes detailed security, auto CRUD generation for your models, google charts and much more.

Lots of `examples <https://github.com/dpgaspar/Flask-AppBuilder/tree/master/examples>`_
and a live `Demo <http://flaskappbuilder.pythonanywhere.com/>`_ (login has guest/welcome).

Fixes, bugs and contributions
-----------------------------

You're welcome to report bugs, propose new features, or even better contribute to this project.

`Issues, bugs and new features <https://github.com/dpgaspar/Flask-AppBuilder/issues/new>`_

`Contribute <https://github.com/dpgaspar/Flask-AppBuilder/fork>`_


Contents:
---------

.. toctree::
   :maxdepth: 1

   intro
   installation
   cli
   config

.. toctree::
   :maxdepth: 1

   views
   quickhowto
   rest_api
   quickcharts
   quickfiles
   quickminimal

.. toctree::
   :maxdepth: 1

   relations
   actions
   advanced
   customizing
   templates

.. toctree::
   :maxdepth: 1

   addons
   generic_datasource
   multipledbs
   i18n

.. toctree::
   :maxdepth: 1

   security
   user_registration

.. toctree::
   :maxdepth: 1

   diagrams
   api
   versionmigration
   breaking

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

